import type { MaintOrderGroupVO, MaintOrderVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  maintOrderExport = '/eims/maintOrder/export',
  maintOrderGroupList = '/eims/maintOrder/groupList',
  maintOrderGroupDetailList = '/eims/maintOrder/detailList',
  maintOrderList = '/eims/maintOrder/list',
  root = '/eims/maintOrder'
}

/**
 * 查询保养工单列表
 * @param query
 * @returns {*}
 */

export function listMaintOrder(params?: any) {
  return requestClient.get<MaintOrderVO[]>(Api.maintOrderList, { params });
}

export function listMaintOrderGroup(params?: any) {
  return requestClient.get<MaintOrderGroupVO[]>(Api.maintOrderGroupList, { params });
}

export function listMaintOrderGroupDetail(params?: any) {
  return requestClient.get<MaintOrderVO[]>(Api.maintOrderGroupDetailList, { params });
}

/**
 * 查询保养工单详细
 * @param maintOrderId
 */
export function getMaintOrder(maintOrderId: ID) {
  return requestClient.get<MaintOrderVO>(`${Api.root}/${maintOrderId}`);
}

/**
 * 新增保养工单
 * @param data
 */
export function addMaintOrder(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改保养工单
 * @param data
 */
export function updateMaintOrder(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除保养工单
 * @param maintOrderId
 */
export function delMaintOrder(maintOrderId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${maintOrderId}`);
}
/**
 * 导出
 * @param
 */
export function maintOrderExport(data: any) {
  return commonExport(Api.maintOrderExport, data);
}
